<?php
/**
 * @license © 2018, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */
namespace ServiceModule;

class NewerPresenter extends \ServiceModule\BasePresenter{
	
	private $mainRepository;
	private $systemSettingsRepository;
	
	public function __construct(\Nette\DI\Container $container) {
		\Tracy\Debugger::enable(TRUE);
		parent::__construct();
		$this->container = $container;
		$this->httpResponse = $this->container->getByType('\Nette\Http\Response');
	}
	
	public function startup() {
		parent::startup();
		$this->mainRepository = $this->context->getService("taxonRepository");
		$this->systemSettingsRepository = $this->context->getService('systemSettingsRepository');
	}
	
	/**
	 * Get JSON of families
	 * @param type $type Type of output
	 */
	public function actionReadAll(){
		$params = $this->getRequest()->getParameter('query');
		
		if(isset($params['date'])){
			$items= $this->mainRepository->getNewer($params['date']);
			$name = $this->systemSettingsRepository->getName();
			$xml = '<?xml version="1.0" encoding="UTF-8"?>';
			$xml .= "<data>\n";
			foreach($items as $item){
				$xml .= "<row>\n";
				$xml .= "<ID>".htmlspecialchars($item->getId())."</ID>\n";
				$xml .= "<Family>".htmlspecialchars($item->familyname)."</Family>\n";
				$xml .= "<GenusHybridMarker>".htmlspecialchars($item->genushybridmarker)."</GenusHybridMarker>\n";     
				$xml .= "<Genus>".htmlspecialchars($item->genus)."</Genus>\n"; 
				$xml .= "<InfraGenericMarker>".htmlspecialchars($item->infragenericmarker)."</InfraGenericMarker>\n"; 
				$xml .= "<InfraGenericEpitet>".htmlspecialchars($item->infragenericep)."</InfraGenericEpitet>\n";
				$xml .= "<InfraGenericAuthor>".htmlspecialchars($item->infragenericauthor)."</InfraGenericAuthor>\n";
				$xml .= "<SpeciesHybridMarker>".htmlspecialchars($item->specieshybridmarker)."</SpeciesHybridMarker>\n";
				$xml .= "<AggregatMarker>".htmlspecialchars($item->aggregatmarker)."</AggregatMarker>\n";
				$xml .= "<SpeciesEpitet>".htmlspecialchars($item->speciesep)."</SpeciesEpitet>\n";
				$xml .= "<SpeciesAuthor>".htmlspecialchars($item->speciesauthor)."</SpeciesAuthor>\n";
				$xml .= "<InfraSpecificMarker>".htmlspecialchars($item->infraspecificmarker)."</InfraSpecificMarker>\n";
				$xml .= "<InfraSpecificEpitet>".htmlspecialchars($item->infraspecificep)."</InfraSpecificEpitet>\n";
				$xml .= "<InfraSpecificAuthor>".htmlspecialchars($item->infraspecificauthor)."</InfraSpecificAuthor>\n";
				$xml .= "<CultivGroupMarker>".htmlspecialchars($item->cultivgroupmarker)."</CultivGroupMarker>\n";
				$xml .= "<CultivMarker>".htmlspecialchars($item->cultivmarker)."</CultivMarker>\n";
				$xml .= "<CultivName>".htmlspecialchars($item->cultivname)."</CultivName>\n";
				$xml .= "<CZName>".htmlspecialchars($item->czname)."</CZName>\n";
				$xml .= "<Note>".htmlspecialchars($item->note)."</Note>\n";
				$xml .= "<Add>".$item->add."</Add>\n";
				$xml .= "<IdNew>".$item->idnew."</IdNew>\n";
				$xml .= "<Edit>".$item->edit."</Edit>\n";
				$xml .= "<Name>".$name."</Name>\n";
				$xml .= "</row>\n";
			}
			$xml .= "</data>";
			$this->sendResponse(new \Nette\Application\Responses\TextResponse($xml));
		}else{
			$this->sendPaymentRequired();
		}	

	}
}