<?php
/**
 * @license © 2015, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */

class DownloadMapper {
    use Nette\SmartObject;
    private $database;
    
    public function __construct(Nette\Database\Context $database){
        $this->database = $database;
    }
    
    public function getCount(){
        $row = $this->database->query("SELECT count(cId) as count FROM taxony_tblDownload")->fetch();
        return $row['count'];
    }
    
    public function getLast(){
        $row = $this->database->query("SELECT DATE_FORMAT(cTime,'%d. %m. %Y %H:%i:%S') AS cTime FROM taxony_tblDownload ORDER BY cTime DESC LIMIT 1")->fetch();
        return $row['cTime'];
    }
    
    public function isDeleteOk($time){
        $res = $this->database->query("SELECT count(cId) AS count FROM taxony_tblDownload WHERE cTime > ?",$time)->fetch();
        if($res['count'] == 0){
            return TRUE;
        }else{
            return FALSE;
        }
    }
    
    public function save($item){
        $data = $this->item2data($item);
        $res = NULL;
        
        try{
            //insert new user
            $this->database->table('taxony_tblDownload')->insert($data);
            $res = true;
        } catch (Exception $e) {
            $res = false;
        }
        return $res;
    }
    
    /**
     * Return array with DownloadItems
     * @param Recordset $rows
     * @return array
     */
    private function getItems($rows){
        $items = NULL;
        foreach($rows as $value){
            $items[] = $this->load($value);
        }
        return $items;
    }
    
    /**
     * Load table records as DownloadItems
     * @param type $data
     * @return \DownloadItem
     */
    public function load($data){
        $item = new DownloadItem;
        $this->setIdentity($item, $data->cId);
        return $this->setItem($data,$item);
    }
    
    /**
     * Set id of TaxonItem
     * @param item	TaxonItem
     * @param id	hodnota nastavovaneho identifikatoru entity TaxonItem
     * @retur		UserItem
     */
    public function setIdentity($item, $id){
        $ref = new Nette\Reflection\ClassType($item);
        $idProp = $ref->getProperty('id');
        $idProp->setAccessible(TRUE);
        $idProp->setValue($item, $id);
        return $item;
    }
    
    /**
     * Set properties of DownloadItem (except id) from array
     * @param $data	array with values
     * @param $item	object DownloadItem
     * @return		TaxonItem
     */
    private function setItem($data,$item){
        $item->time = $data->cTime;
        return $item;
    }
    
    /**
     * Convert named array with item name to named array with name of column from table taxony_tblDownload
     * @param type $item
     * @return type
     */
    private function item2data($item){
        $data['cTime'] = $item['time'];
        return $data;
    }
}
