<?php
/**
 * @license © 2016, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */
class ExportModel {
	use Nette\SmartObject;
	private $dir;
	private $collection;
	private $filename;
	private $name;


	public function __construct() {
		$this->dir = dirname(__FILE__)."/../../export/";
	}
	
	public function setUp($collection, $filename,$name){
		$this->collection = $collection;
		$this->filename = $filename;
		$this->name = $name;
	}
	
	public function start(){
		try{
			$this->deleteOldFiles();
			$checklist = $this->getXML();
			$this->write($checklist);
		} catch (Exception $e){
			return FALSE;
		}
	}
	
	/**
	 * delete files older then specific time in folder /export
	 */
	private function deleteOldFiles(){
		$folder = opendir($this->dir);
		while ($filename = readdir($folder)){
			$filetime = filectime($this->dir.'/'.$filename);
			if($filetime< (time()-86400)&& is_file($this->dir.'/'.$filename)){
				unlink($this->dir.'/'.$filename);
			}
		}
	}
	
	/**
	 * Get xml string with checklist
	 * @param type $collection
	 */
	private function getXML(){
		$count = 0;
		$xml = '<?xml version="1.0" encoding="UTF-8"?>';
		$xml .= "\n<data>\n";
		if($this->collection){
			foreach($this->collection as $row){
				$xml .="<row>\n";
				$xml .= "<ID>".$row->getId()."</ID>\n";
				$xml .= "<Family>".htmlspecialchars($row->familyname)."</Family>\n"; 
				$xml .= "<GenusHybridMarker>".htmlspecialchars($row->genushybridmarker)."</GenusHybridMarker>\n";     
				$xml .= "<Genus>".htmlspecialchars($row->genus)."</Genus>\n"; 
				$xml .= "<InfraGenericMarker>".htmlspecialchars($row->infragenericmarker)."</InfraGenericMarker>\n"; 
				$xml .= "<InfraGenericEpitet>".htmlspecialchars($row->infragenericep)."</InfraGenericEpitet>\n";
				$xml .= "<InfraGenericAuthor>".htmlspecialchars($row->infragenericauthor)."</InfraGenericAuthor>\n";
				$xml .= "<SpeciesHybridMarker>".htmlspecialchars($row->specieshybridmarker)."</SpeciesHybridMarker>\n";
				$xml .= "<AggregatMarker>".htmlspecialchars($row->aggregatmarker)."</AggregatMarker>\n";
				$xml .= "<SpeciesEpitet>".htmlspecialchars($row->speciesep)."</SpeciesEpitet>\n";
				$xml .= "<SpeciesAuthor>".htmlspecialchars($row->speciesauthor)."</SpeciesAuthor>\n";
				$xml .= "<InfraSpecificMarker>".htmlspecialchars($row->infraspecificmarker)."</InfraSpecificMarker>\n";
				$xml .= "<InfraSpecificEpitet>".htmlspecialchars($row->infraspecificep)."</InfraSpecificEpitet>\n";
				$xml .= "<InfraSpecificAuthor>".htmlspecialchars($row->infraspecificauthor)."</InfraSpecificAuthor>\n";
				$xml .= "<CultivGroupMarker>".htmlspecialchars($row->cultivgroupmarker)."</CultivGroupMarker>\n";
				$xml .= "<CultivMarker>".htmlspecialchars($row->cultivmarker)."</CultivMarker>\n";
				$xml .= "<CultivName>".htmlspecialchars($row->cultivname)."</CultivName>\n";
				$xml .= "<CZName>".htmlspecialchars($row->czname)."</CZName>\n";
				$xml .= "<Note>".htmlspecialchars($row->note)."</Note>\n";
				$xml .= "<IdNew>".$row->idnew."</IdNew>\n";
				$xml .= "<Add>".$row->add."</Add>\n";
				$xml .= "<Edit>".$row->edit."</Edit>\n";
				$xml .= "<Name>".$this->name."</Name>\n";
				$xml .= "</row>\n";
				$count++;
			}
		}
		$xml = $xml."</data>";
		return $xml;
	}
	
	private function write($xml){
		$file = fopen("compress.bzip2://".$this->dir.$this->filename,"w");
		fwrite($file, $xml);
		fclose($file);
	}
	
	public function getFileName(){
		$randnum = rand(0,999);
		$datum = StrFTime("%d-%m-%Y-%H-%M-%S", Time());
		return "checklist_".$datum."_".$randnum.".bz2";
	}
}
