<?php
/**
 * @license © 2015, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */

class FamilyMapper 
{
	use Nette\SmartObject;
	private $database;


	public function __construct(Nette\Database\Context $database){
		$this->database = $database;
	}

	public function delete($id) {
		$this->database->query("DELETE FROM taxony_tblFamilies WHERE cId = ?",$id);
	}

	/**
	 * Find specific taxon by parameters
	 * @param	$data	Array vith column name, data type and value
	 * @return	TaxonItem
	 */
	public function findBy($data){
		$dbcolumn = $this->getDbColumn($data['column']);
		$rows = $this->database->query("SELECT * FROM taxony_tblFamilies WHERE ".$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$data['value'])->fetchAll();
		return $this->getItems($rows);
	}

	/**
	 * Get count of users
	 */
	public function getCount($where = NULL){
		if($where == NULL){
			$row = $this->database->query('SELECT count(taxony_tblFamilies.cId) AS count FROM taxony_tblFamilies')->fetch();
			return $row->count;
		}else{
			$dbcolumn = $this->getDbColumn($where['column']);
			$row = $this->database->query('SELECT count(taxony_tblFamilies.cId) AS count FROM taxony_tblFamilies WHERE '.$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$where['value'])->fetch();
			return $row->count;
		}
	}

	public function getAll($length, $offset, $order = NULL, $where = NULL) {
		$rows = NULL;
		if($order == NULL){
			$orderdb = 'cId ASC';
		}else{
			foreach($order as $key=>$value){
				$dbcolumn = $this->getDbColumn($key);
				$orderdb = $dbcolumn['column']." ".$value;
			}
		}

		if($where != NULL){
			$dbcolumn = $this->getDbColumn($where['column']);
			$rows = $this->database->query("SELECT * FROM taxony_tblFamilies WHERE ".$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$where['value']," ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
		}else{
			$rows = $this->database->query("SELECT * FROM taxony_tblFamilies ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
		}
		return $this->getItems($rows);
	}

	/**
	 * Insert new family
	 * @param array $item
	 * @return boolean
	 */
	public function save(array $item)
    {
        $data = $this->item2data($item);
        $res = NULL;
        if ($item['id']===NULL){
            try{
                //insert new family
                $this->database->table('taxony_tblFamilies')->insert($data);
                $res = true;
            } catch (Exception $ex) {
                $res = false;
            }

        }else{
            //update old family
            try{
                $this->database->query('UPDATE taxony_tblFamilies SET', $data,'WHERE cId = ?',$data['cId']);
                unset($data['cId']);
                $res = true;
            }catch(Exception $e){
                $res = false;
            }
        }
        return $res;
    }

	private function getDbColumn($name){
		switch($name){
			case('id'): return array('column'=>'taxony_tblFamilies.cId','datatype'=>'i','operator'=>"=");
			case('userid'): return array('column'=>'taxony_tblFamilies.cUserId','datatype'=>'i','operator' =>'=');
			case('name'): return array('column'=>'taxony_tblFamilies.cName','datatype'=>'s','operator' =>'like');
		}
	}

	/**
	 * Return array with FamilyItems
	 * @param Recordset $rows
	 * @return array
	 */
	private function getItems($rows){
		$items = NULL;
		foreach($rows as $value){
			$items[] = $this->load($value);
		}
		return $items;
	}

	/**
	 * Load table records as FamilyItems
	 * @param type $data
	 * @return \TaxonItem
	 */
	public function load($data){
		$item = new FamilyItem;
		$this->setIdentity($item, $data->cId);
		return $this->setItem($data,$item);
	}

	/**
	 * Set properties of TaxonItem (except id) from array
	 * @param $data	array with values
	 * @param $item	object TaxonItem
	 * @return		FamilyItem
	 */
	private function setItem($data,$item){
		$item->name = $data->cName;
		$item->add = $data->cAdd;
		$item->edit = $data->cEdit;
		$item->userid = $data->cUserId;
		$item->change = $data->cChange;
		return $item;
	}

	/**
	 * Set id of FamilyItem
	 * @param item	FamilyItem
	 * @param id	hodnota nastavovaneho identifikatoru entity FamilyItem
	 * @retur		FamilyItem
	 */
	public function setIdentity($item, $id){
		$ref = new Nette\Reflection\ClassType($item);
		$idProp = $ref->getProperty('id');
		$idProp->setAccessible(TRUE);
		$idProp->setValue($item, $id);
		return $item;
	}

	/**
	 * Convert named array with item name to named array with name of column from table taxony_tblTaxons
	 * @param type $item
	 * @return type
	 */
	private function item2data($item){
		if($item['id']){
			$data['cId'] = $item['id'];
		}
		$data['cName'] = $item['name'];
		if(isset($item['add'])){
			$data['cAdd'] = $item['add'];
		}
		if(isset($item['edit'])){
			$data['cEdit'] = $item['edit'];
		}
		if(isset($item['userid'])){
			$data['cUserId'] = $item['userid'];
		}
		if(isset($item['change'])){
			$data['cChange'] = $item['change'];
		}
		return $data;
	}
}