<?php
/**
 * Repository of function, what it handles with information about families
 * @license © 2020, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */
class FamilyRepository {
	use Nette\SmartObject;
	private $mapper;

	public function __construct(FamilyMapper $mapper){
		$this->mapper = $mapper;
	}

	/**
	 * Get all users
	 * @return \lazyCollection
	 */
	public function getDataSource($length, $offset,$order=null,$where = null){
		return $this->mapper->getAll($length, $offset, $order, $where);
	}

	public function findById($id){
		$items = $this->mapper->findBy(array('column' => 'id','value' => $id, 'datatype' => 's'));
		$idItem = NULL;
		foreach($items as $item){
			$idItem = $item;
		}
		return $idItem;
	}

	/**
	 * Save family
	 * @param array $values
	 * @return boolean
	 */
	public function save(array $values){
		return $this->mapper->save($values);
	}

	/**
	 * Delete specific family by id
	 * @param type $id
	 */
	public function delete($id){
		$this->mapper->delete($id);
	}

	/**
	 * Update specific family
	 * @param array $value
	 */
	public function update(array $value){
		return $this->mapper->update($value);
	}
	
	public function getAllArr(){
		$items = $this->mapper->getAll(1000, 0, array('name'=>'ASC'), NULL);
		$result = NULL;
		foreach($items as $item){
			$result[$item->getId()] = $item->name;
		}
		return $result;
	}
	
	public function getIdNameArray($sample){
		$items = $this->mapper->findBy(array('column'=>'name','value'=>$sample, 'datatype' => 's'));
		$data= null;
		if(count($items)){
			foreach($items as $item){
				$data[] = array('id'=>$item->getId(),'name'=>$item->name);
			}
		}
		return $data;
	}
}