<?php

class SystemSettingsMapper
{
	use Nette\SmartObject;
	private $database;
	private $sql;
	
	public function __construct(Nette\Database\Context $database){
		$this->database = $database;
		$this->sql = "SELECT cId, cKey, cValue FROM taxony_tblSystemSettings";
	}
	
	/**
	 * Convert named array with name of item to named array with name of column from table vraticka_tblUserSettings
	 * @param array $item
	 * @return null
	*/
	protected function item2data($item){
		$data = null;
		$data['cValue'] = $item['value'];
		$data['cKey'] = $item['key'];
		return $data;
	}
	
	/**
	 * Save or update specific user's setting
	 * @param array $item
	 * @throws Exception
	 * $return boolean
	 */
	public function save(array $item){
		$data = $this->item2data($item);
		$res = null;
		if ($item['id']==null){
			try{
				//insert new setting
				$this->database->table('taxony_tblSystemSettings')->insert($data);
				$res = true;
			}catch(exception $e){
				$res = false;
			}
		}else{
			//update old setting
			try{
				$this->database->query('SET AUTOCOMMIT = 0;');
				$this->database->query('START TRANSACTION;');
				$this->database->query('UPDATE taxony_tblSystemSettings SET cKey = ?', $item['key'],'WHERE cId = ?',$item['id']);
				$this->database->query('UPDATE taxony_tblSystemSettings SET cValue = ?', $item['value'],'WHERE cId = ?',$item['id']);
				$this->database->query('COMMIT;');
				$res = true;
			}catch(Exception $e){
				$res = false;
			}
			unset($item['cId']);
		}
		return $res;
	}
	
	/**
	* Get name of column from database
	* @param string $name
	 * @return string
	 */
	protected function getDbColumn($name){
		switch ($name){
			case('id'):return array('column'=>'taxony_tblSystemSettings.cId','datatype'=>'i','operator'=>'=');
			case('key'):return array('column'=>'taxony_tblSystemSettings.cKey','datatype'=>'s','operator'=>'=');
		}
	}
	
	/**
	 * Set properties of UserSettingItem (except id) from array
	 * @param $data	array with values
	 * @param $item	object UserSettingItem
	 * @return		UserSettingItem
	 */
	protected function setItem($data,$item){
		$item->key = $data['cKey'];
		$item->value = $data['cValue'];
		return $item;
	}

	/**
	 * Load record of relevant tables as UserSettingItem
	 * @param array $data
	 * @return UserSettingItem
	*/
	public function load($data){
		$item = new SystemSettingItem;
		$this->setIdentity($item, $data->cId);
		return $this->setItem($data,$item);
	}
	
	/**
	 * Set id of Item
	 * @param item	Item
	 * @param id	hodnota nastavovaneho identifikatoru entity Item
	 * @retur		Item
	 */
	protected function setIdentity($item, $id){
		$ref = new Nette\Reflection\ClassType($item);
		$idProp = $ref->getProperty('id');
		$idProp->setAccessible(TRUE);
		$idProp->setValue($item, $id);
		return $item;
	}
	
	/**
	 * Delete settings
	 */
	public function delete(){
		$this->database->query('DELETE FROM `taxony_tblSystemSettings`');
	}
	
	/**
	 * Find specific items by 1 parameter
	 * @param	array $data	Array vith column name, data type and value
	 * @return	array of Item
	 */
	public function findBy($data){
		$columnParam = $this->getDbColumn($data['column']);
		if(isset($data['orderColumn']) && isset($data['orderMethod'])){
			$columnOrd = $this->getDbColumn($data['orderColumn']);
			$data['orderColumn'] = $columnOrd['column'];
		}else{
			$data['orderColumn'] = $columnParam['column'];
			$data['orderMethod'] = 'ASC';
		}
		$rows = $this->database-> query($this->sql." WHERE ".$columnParam['column'].' '.$columnParam['operator']. ' '.$this->getCorrectValue($columnParam['datatype'],$data['value']).$this->getCondDeleted($data)." ORDER BY ".$data['orderColumn'].' '.$data['orderMethod']);
		return $this->getItems($rows);
	}
	
	/**
	 * Get correct value for database query
	 * @param type $datatype
	 * @param type $value
	 * @return mixed
	 */
	public function getCorrectValue($datatype, $value){
		switch($datatype){
			case("s"): return "'".addslashes($value)."'";
			case("d"): return "'".addslashes($value)."'";
			case("i"): return $this->getCorrectNumber($value);
		}
	}

	/**
	 * get correct number
	 * @param input
	 * @return number
	 */
	public function getCorrectNumber($input){
		if(is_null($input)){
			return NULL;
		}
		$number = NULL;
		if(is_numeric($input)==FALSE){
			$number = 0;
		}else{
			$number = $input;
		}
		return $number;
	}
	
	/**
	 * get condition for parameter deleted
	 * @param array $data
	 * @return string
	 */
	protected function getCondDeleted($data){
		$result = "";
		if(isset($data['deleted'])){
			$columnParam = $this->getDbColumn('deleted');
			if($data['deleted'] === 1){
				$result = " AND ".$columnParam['column']." IS NULL";
			}
			if($data['deleted'] === 2){
				$result = " AND ".$columnParam['column']." IS NOT NULL";
			}
		}
		return $result;
	}
	
	/**
	* Return array with UserItems
	* @param ResultSet $rows
	* @return array
	*/
	protected function getItems($rows){
		$items = null;
		foreach($rows as $value){
			$items[] = $this->load($value);
		}
		return $items;
	}
}