<?php
/**
 * @license © 2015, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */

class TaxonMapper 
{
	use Nette\SmartObject;
	private $database;
	private $sql;


	public function __construct(Nette\Database\Context $database){
		$this->database = $database;
		$this->sql = "SELECT taxony_tblTaxons.cId AS cId, taxony_tblTaxons.cGenusHybridMarker AS cGenusHybridMarker, taxony_tblTaxons.cGenus AS cGenus, taxony_tblTaxons.cInfraGenericMarker AS cInfraGenericMarker, taxony_tblTaxons.cInfraGenericEp, taxony_tblTaxons.cInfraGenericAuthor AS cInfraGenericAuthor, taxony_tblTaxons.cSpeciesHybridMarker AS cSpeciesHybridMarker, taxony_tblTaxons.cAggregatMarker AS cAggregatMarker, taxony_tblTaxons.cSpeciesEp AS cSpeciesEp, taxony_tblTaxons.cSpeciesAuthor AS cSpeciesAuthor, taxony_tblTaxons.cInfraSpecificMarker AS cInfraSpecificMarker, taxony_tblTaxons.cInfraSpecificEp AS cInfraSpecificEp, taxony_tblTaxons.cInfraSpecificAuthor AS cInfraSpecificAuthor, taxony_tblTaxons.cCultivGroupMarker AS cCultivGroupMarker, taxony_tblTaxons.cCultivMarker AS cCultivMarker, taxony_tblTaxons.cCultivName AS cCultivName, taxony_tblTaxons.cCZName AS cCZName, taxony_tblTaxons.cNote AS cNote, taxony_tblTaxons.cAdd AS cAdd, taxony_tblTaxons.cEdit AS cEdit, taxony_tblTaxons.cUserId as cUserId, taxony_tblTaxons.cChange AS cChange, taxony_tblTaxons.cFamily AS cFamily, taxony_tblTaxons.cIdnew AS cIdNew, taxony_tblFamilies.cName AS cFamilyName  FROM taxony_tblTaxons JOIN taxony_tblFamilies ON taxony_tblFamilies.cId = taxony_tblTaxons.cFamily";
	}

	public function delete($id) {
		$this->database->query("DELETE FROM taxony_tblTaxons WHERE cId = '".$id."'");
	}

	/**
	 * Find specific taxon by parameters
	 * @param	$data	Array vith column name, data type and value
	 * @return	TaxonItem
	 */
	public function findBy($data){
		$dbcolumn = $this->getDbColumn($data['column']);
		$rows = $this->database->query($this->sql." WHERE ".$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$data['value'])->fetchAll();
		return $this->getItems($rows);
	}

	/**
	 * Get count of users
	 */
	public function getCount($where = NULL){
		if($where == NULL){
			$row = $this->database->query('SELECT count(taxony_tblTaxons.cId) AS count FROM taxony_tblTaxons')->fetch();
			return $row->count;
		}else{
			$dbcolumn = $this->getDbColumn($where['column']);
			$row = $this->database->query('SELECT count(taxony_tblTaxons.cId) AS count FROM taxony_tblTaxons WHERE '.$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$where['value'])->fetch();
			return $row->count;
		}
	}

	public function getAll($length, $offset, $order = NULL, $where = NULL) {
		$rows = NULL;
		if($order == NULL){
			$orderdb = 'cId ASC';
		}else{
			foreach($order as $key=>$value){
				$dbcolumn = $this->getDbColumn($key);
				$orderdb = $dbcolumn['column']." ".$value;
			}
		}

		if($where != NULL){
			$whereclause = $this->getWhereClause($where);
			$rows = $this->database->query($this->sql.$whereclause." ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
		}else{
			$rows = $this->database->query($this->sql." ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
		}
		return $this->getItems($rows);
	}
	
	public function getLastUpdate(){
		$date = $this->database->fetch("SELECT  DATE_FORMAT(MAX(cEdit),'%Y-%m-%d %H:%i:%s') as date FROM taxony_tblTaxons");
		return $date['date'];
	}

	/**
	 * Insert taxon
	 * @param array $item
	 * @return boolean
	 */
	public function save(array $item){
		$data = $this->item2data($item);
		$res = NULL;
		try{
			$this->database->table('taxony_tblTaxons')->insert($data);
			$res = true;
		}catch(Exception $e) {
			$res = false;
		}
		return $res;
	}

	/**
	 * Update taxon
	 * @param array $item
	 * @return boolean
	 */
	public function update(array $item){
		$data = $this->item2data($item);
		$res = NULL;
		try{
			$this->database->query('SET AUTOCOMMIT = 0;');
			$this->database->query('START TRANSACTION;');
			$this->database->query('UPDATE taxony_tblTaxons SET', $data,'WHERE cId = ?',$data['cId']);
			$this->database->query('COMMIT');
			unset($data['cId']);
			$res = true;
		}catch(Exception $e){
			$res = false;
		}
		return $res;
	}
	
	public function deleteChange($oldid, $newid){
		try{
			$this->database->query('SET AUTOCOMMIT = 0;');
			$this->database->query('START TRANSACTION;');
			if($newid != null){
				$this->database->query('UPDATE taxony_tblTaxons SET cEdit = NOW(), cIdNew = ?', $newid ,'WHERE cId = ?',$oldid);
			}else{
				$this->database->query('UPDATE taxony_tblTaxons SET cIdnew = NULL, cEdit = NOW() WHERE cId = ?',$oldid);
			}
			$this->database->query('COMMIT');
			$res = true;
		}catch(Exception $e){
			$res = false;
		}
		return $res;
	}

	private function getDbColumn($name){
		switch($name){
			case('id'): return array('column'=>'taxony_tblTaxons.cId','datatype'=>'i','operator'=>"=");
			case('userid'): return array('column'=>'taxony_tblTaxons.cUserId','datatype'=>'i','operator' =>'=');
			case('family'): return array('column'=>'taxony_tblTaxons.cFamily','datatype'=>'i','operator' =>'=');
			case('edit'): return array('column'=>'taxony_tblTaxons.cEdit','datatype'=>'s','operator' =>'>');
		}
	}

	/**
	 * Return array with TaxonItems
	 * @param Recordset $rows
	 * @return array
	 */
	private function getItems($rows){
		$items = NULL;
		foreach($rows as $value){
			$items[] = $this->load($value);
		}
		return $items;
	}

	/**
	 * Load table records as TaxonItems
	 * @param type $data
	 * @return \TaxonItem
	 */
	public function load($data){
		$item = new TaxonItem;
		$this->setIdentity($item, $data->cId);
		return $this->setItem($data,$item);
	}

	/**
	 * Set properties of TaxonItem (except id) from array
	 * @param $data	array with values
	 * @param $item	object TaxonItem
	 * @return		TaxonItem
	 */
	private function setItem($data,$item){
		$item->genushybridmarker = $data->cGenusHybridMarker;
		$item->genus = $data->cGenus;
		$item->infragenericmarker = $data->cInfraGenericMarker;
		$item->infragenericep = $data->cInfraGenericEp;
		$item->infragenericauthor = $data->cInfraGenericAuthor;
		$item->specieshybridmarker = $data->cSpeciesHybridMarker;
		$item->aggregatmarker = $data->cAggregatMarker;
		$item->speciesep = $data->cSpeciesEp;
		$item->speciesauthor = $data->cSpeciesAuthor;
		$item->infraspecificmarker = $data->cInfraSpecificMarker;
		$item->infraspecificep = $data->cInfraSpecificEp;
		$item->infraspecificauthor = $data->cInfraSpecificAuthor;
		$item->cultivgroupmarker = $data->cCultivGroupMarker;
		$item->cultivmarker = $data->cCultivMarker;
		$item->cultivname = $data->cCultivName;
		$item->czname = $data->cCZName;
		$item->note = $data->cNote;
		$item->add = $data->cAdd;
		$item->edit = $data->cEdit;
		$item->userid = $data->cUserId;
		$item->family = $data->cFamily;
		$item->familyname = $data->cFamilyName;
		$item->idnew = $data->cIdNew;
		return $item;
	}

	/**
	 * Set id of TaxonItem
	 * @param item	TaxonItem
	 * @param id	hodnota nastavovaneho identifikatoru entity TaxonItem
	 * @retur		Taxontem
	 */
	public function setIdentity($item, $id){
		$ref = new Nette\Reflection\ClassType($item);
		$idProp = $ref->getProperty('id');
		$idProp->setAccessible(TRUE);
		$idProp->setValue($item, $id);
		return $item;
	}

	/**
	 * Convert named array with item name to named array with name of column from table taxony_tblTaxons
	 * @param type $item
	 * @return type
	 */
	private function item2data($item){
		if($item['id']){
			$data['cId'] = $item['id'];
		}
		$data['cGenusHybridMarker'] = $item['genushybridmarker'];
		$data['cGenus'] = $item['genus'];
		$data['cInfraGenericMarker'] = $item['infragenericmarker'];
		$data['cInfraGenericEp'] = $item['infragenericep'];
		$data['cSpeciesHybridMarker'] = $item['specieshybridmarker'];
		$data['cAggregatMarker'] = $item['aggregatmarker'];
		$data['cSpeciesEp'] = $item['speciesep'];
		$data['cSpeciesAuthor'] = $item['speciesauthor'];
		$data['cInfraSpecificMarker'] = $item['infraspecificmarker'];
		$data['cInfraSpecificEp'] = $item['infraspecificep'];
		$data['cInfraSpecificAuthor'] = $item['infraspecificauthor'];
		$data['cCultivGroupMarker'] = $item['cultivgroupmarker'];
		$data['cCultivMarker'] = $item['cultivmarker'];
		$data['cCultivName'] = $item['cultivname'];
		$data['cCZName'] = $item['czname'];
		$data['cNote'] = $item['note'];
		$data['cFamily'] = $item['family'];
		if(isset($item['add'])){
			$data['cAdd'] = $item['add'];
		}
		if(isset($item['edit'])){
			$data['cEdit'] = $item['edit'];
		}
		if(isset($item['userid'])){
			$data['cUserId'] = $item['userid'];
		}
		if(isset($item['change'])){
			$data['cChange'] = $item['change'];
		}
		return $data;
	}

	/*public function setNewAcceptNames($old,$new){
		$this->database->query('UPDATE taxony_tblTaxons SET cID_tax = ?',$new,' WHERE cId_tax = ?',$old);
	}*/
	
	public function getWhereClause($where = NULL){
		$whereclause = null;
		if($where== null){
			return "";
		}else{
			$whereclause = " WHERE ";
		}
		
		if(isset($where['id'])){
			$whereclause .= "taxony_tblTaxons.cId = '".addslashes($where['id'])."'";
		}
		
		if(isset($where['userid'])){
			$whereclause = $this->addAND($whereclause);
			$whereclause .= "taxony_tblTaxons.cUserId = '".addslashes($where['userid'])."'";
		}
		
		if(isset($where['family'])){
			$whereclause = $this->addAND($whereclause);
			$whereclause .= "taxony_tblTaxons.cFamily = '".addslashes($where['family'])."'";
		}
		
		if(isset($where['genus'])){
			$whereclause = $this->addAND($whereclause);
			$whereclause .= "taxony_tblTaxons.cGenus = '".addslashes($where['genus'])."'";
		}
		
		$whereclause = $this->addAND($whereclause);
		if(isset($where['infragenericep'])){
			$whereclause .= "taxony_tblTaxons.cInfraGenericEp = '".addslashes($where['infragenericep'])."'";
		}else{
			$whereclause .= "LENGTH(taxony_tblTaxons.cInfraGenericEp) = 0";
		}
		
		$whereclause = $this->addAND($whereclause);
		if(isset($where['aggregatmarker'])){
			$whereclause .= "taxony_tblTaxons.cAggregatMarker = '".addslashes($where['aggregatmarker'])."'";
		}else{
			$whereclause .= "LENGTH(taxony_tblTaxons.cAggregatMarker) = 0";
		}
		
		$whereclause = $this->addAND($whereclause);
		if(isset($where['speciesep'])){
			$whereclause .= "taxony_tblTaxons.cSpeciesEp = '".addslashes($where['speciesep'])."'";
		}else{
			$whereclause .= "LENGTH(taxony_tblTaxons.cSpeciesEp) = 0";
		}
		
		if(isset($where['infraspecificmarker'])){
			$whereclause = $this->addAND($whereclause);
			$whereclause .= "taxony_tblTaxons.cInfraSpecificMarker = '".addslashes($where['infraspecificmarker'])."'";
		}
		
		
		$whereclause = $this->addAND($whereclause);
		if(isset($where['infraspecificep'])){
			$whereclause .= "taxony_tblTaxons.cInfraSpecificEp = '".addslashes($where['infraspecificep'])."'";
		}else{
			$whereclause .= "LENGTH(taxony_tblTaxons.cInfraSpecificEp) = 0";
		}
		
		$whereclause = $this->addAND($whereclause);
		if(isset($where['cultivname'])){
			$whereclause .= "taxony_tblTaxons.cCultivName = '".addslashes($where['cultivname'])."'";
		}else{
			$whereclause .= "LENGTH(taxony_tblTaxons.cCultivName) = 0";
		}
		
		
		if(isset($where['idnew'])){
			$whereclause = $this->addAND($whereclause);
			if(strlen($where['idnew']) == 0){
				$whereclause .= "LENGTH(taxony_tblTaxons.cIdNew) = 0";
			}else{
				$whereclause .= "taxony_tblTaxons.cIdNew = '".addslashes($where['idnew'])."'";
			}
		}
		
		return $whereclause;
	}
	
	/**
	 * Add
	 * @param string $where
	 * @return string
	 */
	private function addAND($where){
		if(strlen($where)>7){
			$where .= ' AND ';
		}
		return $where;
	}
}