<?php
/**
 * Repository of function, what it handles with information about taxons
 * @license © 2015, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */
class TaxonRepository {
	use Nette\SmartObject;
	private $mapper;

	public function __construct(TaxonMapper $mapper){
		$this->mapper = $mapper;
	}

	/**
	 * Get all users
	 * @return \lazyCollection
	 */
	public function getDataSource($length, $offset,$order=null,$where = null){
	return $this->mapper->getAll($length, $offset, $order, $where);
	}

	public function findById($id){
		$items = $this->mapper->findBy(array('column' => 'id','value' => $id, 'datatype' => 's'));
		$idItem = NULL;
		foreach($items as $item){
			$idItem = $item;
		}
		return $idItem;
	}
	
	public function findByAbbrev($abbrev){
		return $this->mapper->findBy(array('column' => 'abbrev','value' => $abbrev, 'datatype' => 's'));
		
	}

	/**
	 * Save or update taxon
	 * @param array $values
	 * @return boolean
	 */
	public function save(array $values){
		return $this->mapper->save($values);
	}

	/**
	 * Delete specific taxon by id
	 * @param type $id
	 */
	public function delete($id){
		$this->mapper->delete($id);
	}
	
	public function deleteChange($oldid, $newid){
		$this->mapper->deleteChange($oldid, $newid);
	}

	/**
	 * Update specific taxon
	 * @param array $value
	 */
	public function update(array $value){
		return $this->mapper->update($value);
	}

	public function getCountUser($userid){
		return $this->mapper->getCount(array('column'=>'userid','value'=>$userid));
	}
	
	public function getCountByFamily($family){
		return $this->mapper->getCount(array('column'=>'family','value'=>$family));
	}
	
	public function getLastUpdate(){
		return $this->mapper->getLastUpdate();
	}
	
	/**
	 * Get newer taxons then date in parameter
	 * @param type $date
	 * @return type
	 */
	public function getNewer($date){
		return $this->mapper->findBy(array('column' => 'edit','value' => $date,'datatype' => 's'));
	}
	
	public function getCountNewer($date){
		return $this->mapper->getCount(array('column'=>'edit','value'=>$date));
	}
}
