<?php
/**
 * @license © 2015, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */

class UserMapper 
{
	use Nette\SmartObject;
    private $database;

    
    public function __construct(\Nette\Database\Context $database){
        $this->database = $database;
    }
    public function delete($id) {
         $this->database->query('DELETE FROM taxony_tblUsers WHERE cId = ?',$id);
    }

    public function findBy($data) {
        $dbcolumn = $this->getDbColumn($data['column']);
        $rows = $this->database->query("SELECT * FROM taxony_tblUsers WHERE ".$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$data['value'])->fetchAll();
		return $this->getItems($rows);
    }

    public function getAll($length, $offset, $order = NULL, $where = NULL) {
        $rows = NULL;
        if($order == NULL){
            $orderdb = 'cId ASC';
        }else{
            foreach($order as $key=>$value){
                $dbcolumn = $this->getDbColumn($key);
                $orderdb = $dbcolumn['column']." ".$value;
            }
        }
        
        if($where != NULL){
            $dbcolumn = $this->getDbColumn($where['column']);
            $rows = $this->database->query("SELECT * FROM taxony_tblUsers WHERE ".$dbcolumn['column'].' '.$dbcolumn['operator'].' ?',$where['value']," ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
        }else{
            $rows = $this->database->query("SELECT * FROM taxony_tblUsers ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
        }
        return $this->getItems($rows);
    }

    /**
     * Insert or update user
     * @param array $item
     * @return boolean
     */
    public function save(array $item)
    {
        $data = $this->item2data($item);
        $res = NULL;
        if ($item['id']===NULL){
            try{
                //insert new user
                $this->database->table('taxony_tblUsers')->insert($data);
                $res = true;
            } catch (Exception $ex) {
                $res = false;
            }

        }else{
            //update old user
            try{
                /*$this->database->query('SET AUTOCOMMIT = 0;');
                $this->database->query('START TRANSACTION;');*/
                $this->database->query('UPDATE taxony_tblUsers SET', $data,'WHERE cId = ?',$data['cId']);
                //$this->database->query('COMMIT');
                unset($data['cId']);
                $res = true;
            }catch(Exception $e){
                $res = false;
            }
        }
        return $res;
    }
    
    private function getDbColumn($name){
        switch($name){
            case('id'): return array('column'=>'taxony_tblUsers.cId','datatype'=>'i','operator'=>"=");
            case('username'): return array('column'=>'taxony_tblUsers.cUserName','datatype'=>'s','operator'=>"=");
            case('password'): return array('column'=>'taxony_tblUsers.cPassword','datatype'=>'s','operator'=>"=");
            case('email'): return array('column'=>'taxony_tblUsers.cEmail','datatype'=>'s','operator'=>"=");
            case('forname'): return array('column'=>'taxony_tblUsers.cFirstName','datatype'=>'s','operator'=>"=");
            case('surname'): return array('column'=>'taxony_tblUsers.cSurName','datatype'=>'s','operator'=>"=");
        }
    }
    
    /**
     * Return array with UserItems
     * @param Recordset $rows
     * @return array
     */
    private function getItems($rows){
        $items = NULL;
        foreach($rows as $value){
            $items[] = $this->load($value);
        }
        return $items;
    }
      
    /**
     * Load table records as UserItems
     * @param type $data
     * @return \UserItem
     */
    public function load($data){
        $item = new UserItem;
        $this->setIdentity($item, $data->cId);
        return $this->setItem($data,$item);
    }
    
    /**
     * Set properties of UserItem (except id) from array
     * @param $data	array with values
     * @param $item	object UserItem
     * @return		UserItem
     */
    private function setItem($data,$item)
    {
	$item->username = $data->cUserName;
        $item->firstname = $data->cFirstName;
	$item->surname = $data->cSurName;
	$item->email = $data->cEmail;
	$item->password = $data->cPassword;
	return $item;
    }
    
    /**
     * Set id of UserItem
     * @param item	UserItem
     * @param id	hodnota nastavovaneho identifikatoru entity UserItem
     * @retur		UserItem
     */
    public function setIdentity($item, $id){
        $ref = new Nette\Reflection\ClassType($item);
        $idProp = $ref->getProperty('id');
        $idProp->setAccessible(TRUE);
        $idProp->setValue($item, $id);
        return $item;
    }
    
    /**
     * Convert named array with item name to named arraz with name of column from table taxony_tblUsers
     * @param type $item
     * @return type
     */
    private function item2data($item)
    {
        $data['cUserName'] = $item['username'];
        if($item['password']){
            $data['cPassword'] = hash('sha256', $item['username']."$".(strlen($item['password']) * strlen($item['username']))."&".$item['password']."#".(strlen($item['password']) + strlen($item['username'])));
        }
        $data['cFirstName'] = $item['firstname'];
        $data['cSurName'] = $item['surname'];
        $data['cEmail'] = $item['email'];
        if($item['id']){
            $data['cId'] = $item['id'];
        }
        return $data;
    }

}