<?php

/**
 * @license © 2016, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */
class UserRepository 
{
	use Nette\SmartObject;
    private $mapper;

    public function __construct(UserMapper $mapper)
    {
        $this->mapper = $mapper;
    }
    
    /**
     * Get all users
     * @return \lazyCollection
     */
    public function getDataSource($length, $offset,$order=null,$where = null){
        return $this->mapper->getAll($length, $offset, $order, $where);
    }
    
    /**
     * Save or update user
     * @param UserItem $item
     * @return boolean
     */
    public function save(array $values){
        return $this->mapper->save($values);
    }
    
    /**
     * Delete specific user by id
     * @param type $userid
     */
    public function delete($userid){
        $this->mapper->delete($userid);
    }
    
    /**
     * Find user by their identifier
     * @param integer $id
     * @return \lazyCollection
     */
    public function findById($id){
        $items = $this->mapper->findBy(array('column'=>'id', 'value'=>$id,'datatype'=>'i'));
        $idItem = NULL;
        foreach($items as $item){
            $idItem = $item;
        }
        return $idItem;
    }
    
    /**
     * Find users by their username
     * @param String $username
     * @return \lazyCollection
     */
    public function findByUserName($username){
        return $this->mapper->findBy(array('column'=>'username', 'value'=>$username,'datatype'=>'s'));
    }
    
    
    
}
