<?php

/**
 * @license © 2016, Vladimír Hans, BSD licence http://opensource.org/licenses/bsd-license.php
 */

class ViewtaxonMapper 
{
	use Nette\SmartObject;
	
	private $database;
	private $sql;
	
	public function __construct(Nette\Database\Context $database) {
		$this->database = $database;
		$this->sql = "SELECT taxony_vwTaxons.cTaxon as cTaxon, taxony_vwTaxons.cTaxonFull AS cTaxonFull, taxony_vwTaxons.cCZName AS cCZName, taxony_vwTaxons.cAdd AS cAdd,taxony_vwTaxons.cId as cId, taxony_vwTaxons.cNote as cNote, taxony_vwTaxons.cEdit AS cEdit, taxony_vwTaxons.cCreator AS cCreator, taxony_vwTaxons.cEditor AS cEditor, taxony_vwTaxons.cFamily AS cFamily, taxony_vwTaxons.cValid AS cValid, taxony_vwTaxonsValid.cTaxon AS cTaxonValid FROM taxony_vwTaxons LEFT JOIN taxony_vwTaxonsValid ON taxony_vwTaxons.cIdNew = taxony_vwTaxonsValid.cId";
	}
	
	private function getCollection($length, $offset, $order = NULL, $where = NULL) {
		$rows = NULL;
		if($order == NULL){
			$orderdb = 'cId ASC';
		}else{
			foreach($order as $key=>$value){
				$dbcolumn = $this->getDbColumn($key);
				$orderdb = $dbcolumn['column']." ".$value;
			}
		}
		
		if($where != NULL){
			$rows = $this->database->query($this->sql.$this->getWhere($where)." ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
		}else{
			$rows = $this->database->query($this->sql."  ORDER BY ".$orderdb." LIMIT ".$length." OFFSET ".$offset)->fetchAll();
		}
		return $this->getItems($rows);
	}
	
	public function getAll($length, $offset, $order = NULL, $where = NULL){
		return $this->getCollection($length, $offset ,$order, $where);
	}
	
	/**
	 * Get count of taxons
	 * @param fragmentWhere string
	 * @param where string 
	 */
	private function getCount($where = NULL){
		if($where == NULL){
			$row = $this->database->query('SELECT count(taxony_vwTaxons.cId) AS count FROM taxony_vwTaxons')->fetch();
			return $row->count;
		}else{
			//$dbcolumn = $this->getDbColumn($where['column']);
			$row = $this->database->query("SELECT count(taxony_vwTaxons.cId) AS count FROM taxony_vwTaxons".$this->getWhere($where))->fetch();
			return $row->count;
		}
	}
	
	
	public function getCountAll($where = NULL){
		return $this->getCount($where);
	}
	
	private function getDbColumn($name){
		switch($name){
			case("id"): return array('column'=>'taxony_vwTaxons.cId','datatype'=>'s','operator'=>"=");
			case("taxon"): return array('column'=>'taxony_vwTaxons.cTaxon','datatype'=>'s','operator'=>"like");
			case("taxonfull"): return array('column'=>'taxony_vwTaxons.cTaxonFull','datatype'=>'s','operator'=>"like");
			case("czname"): return array('column'=>'taxony_vwTaxons.cCZName','datatype'=>'s','operator'=>"like");
			case("add"): return array('column'=>'taxony_vwTaxons.cAdd','datatype'=>'d','operator'=>"=");
			case("note"): return array('column'=>'taxony_vwTaxons.cNote','datatype'=>'s','operator'=>"like");
			case("edit"): return array('column'=>'taxony_vwTaxons.cEdit','datatype'=>'d','operator'=>"=");
			case("creator"): return array('column'=>'taxony_vwTaxons.cCreator','datatype'=>'s','operator'=>"=");
			case("editor"): return array('column'=>'taxony_vwTaxons.cEditor','datatype'=>'s','operator'=>"=");
			case("vaiid"): return array('column'=>'taxony_vwTaxons.cValid','datatype'=>'i','operator'=>"=");
		}
	}
	
	/**
	 * Return array with UserItems
	 * @param Recordset $rows
	 * @return array
	 */
	private function getItems($rows){
		$items = NULL;
		foreach($rows as $value){
			$items[] = $this->load($value);
		}
		return $items;
	}
	
	/**
	 * Load table records as ViewTaxonItems
	 * @param type $data
	 * @return \ViewTaxonItem
	 */
	public function load($data){
		$item = new ViewTaxonItem;
		$this->setIdentity($item, $data->cId);
		return $this->setItem($data,$item);
	}
	
	/**
	 * Set id of UserItem
	 * @param item	UserItem
	 * @param id	hodnota nastavovaneho identifikatoru entity UserItem
	 * @retur		ViewTaxonItem
	 */
	public function setIdentity($item, $id){
		$ref = new Nette\Reflection\ClassType($item);
		$idProp = $ref->getProperty('id');
		$idProp->setAccessible(TRUE);
		$idProp->setValue($item, $id);
		return $item;
	}
	
	/**
	 * Set properties of UserItem (except id) from array
	 * @param $data	array with values
	 * @param $item	object UserItem
	 * @return		ViewTaxonItem
	 */
	private function setItem($data,$item){
		$item->taxon = $data->cTaxon;
		$item->taxonfull = $data->cTaxonFull;
		$item->czname = $data->cCZName;
		$item->add = $data->cAdd;
		$item->note = $data->cNote;
		$item->edit = $data->cEdit;
		$item->creator = $data->cCreator;
		$item->editor = $data->cEditor;
		$item->family = $data->cFamily;
		$item->valid = $data->cValid;
		$item->taxonvalid = $data->cTaxonValid;
		return $item;
	}
	
	private function getWhere($where = NULL){
		$whereclause = NULL;
		if($where== null){
			return "";
		}else{
			$whereclause = " WHERE ";
		}
		if(isset($where['id'])){
			$column = $this->getDbColumn('id');
			$whereclause .= $column['column']." ".$column['operator']." '".addslashes($where['id'])."'";
		}
		if(isset($where['taxon'])){
			$whereclause = $this->addAND($whereclause);
			$column = $this->getDbColumn('taxon');
			$whereclause .= $column['column']." ".$column['operator']." '".addslashes($where['taxon'])."'";
		}
		if(isset($where['taxonfull'])){
			$whereclause = $this->addAND($whereclause);
			$column = $this->getDbColumn('taxonfull');
			$whereclause .= $column['column']." ".$column['operator']." '".addslashes($where['taxonfull'])."'";
		}
		if(isset($where['valid'])){
			$whereclause = $this->addAND($whereclause);
			$column = $this->getDbColumn('vaiid');
			$whereclause .= $column['column']." ".$column['operator']." '".addslashes($where['valid'])."'";
		}
		
		return $whereclause;
	}
	
	/**
	 * Add
	 * @param string $where
	 * @return string
	 */
	private function addAND($where){
		if(strlen($where)>7){
			$where .= ' AND ';
		}
		return $where;
	}
}