<?php

use Nette\Application\UI\Form;
use Nette\Utils\Paginator;
use Nette\Application\Responses\TextResponse;

class HomepagePresenter extends BasePresenter
{
	private $viewTaxonRepository;
	private $sessName;
	private $exportRepository;
	private $taxonRepository;
	private $downloadRepository;
	private $systemSettingsRepository;
	
	public function startup() {
		parent::startup();
		$this->viewTaxonRepository = $this->context->getService('viewtaxonRepository');
		$this->exportRepository = $this->context->getService('exportRepository');
		$this->taxonRepository = $this->context->getService('taxonRepository');
		$this->downloadRepository = $this->context->getService('downloadRepository');
		$this->systemSettingsRepository = $this->context->getService('systemSettingsRepository');
		$this->sessName = 'viewTaxon';
		ini_set("memory_limit","1024M");
	}
	
	
	protected function createComponentSignInForm(){
		$form = new Form();
		$form->addText('username', 'Uživatel', 15, 40)
			->setAttribute('placeholder','Jméno');
		$form->addPassword('password', 'Heslo', 15)
			->setAttribute('placeholder','Heslo');
		$form->addSubmit('login', 'Přihlásit se');
		$form->onSuccess[] = array($this,'signInFormSubmitted');
		return $form;
	}
	
	/**
	 * Process data from login form
	 * @see  createComponentSignInForm()
	 */
	public function signInFormSubmitted(Form $form){
		try {
			$user = $this->getUser();
			$values = $form->getValues();
			$user->login($values->username, $values->password);
			$this->redirect('Homepage:default');
		} catch (Nette\Security\AuthenticationException $e) {
			$form->addError($e->getMessage());
			return;
		}
	}
	
	public function createComponentFilterForm(){
		$session = $this->context->getService('session');
		$filterParam = $session->getSection($this->sessName);
		$form = new Form();
		$form->addText("taxon","Taxon");
		$form->addSubmit('find',"Filtrovat");
		$form->onSuccess[] = array($this, 'processFilterForm');
		$form->setDefaults(array(
			'taxon'=>$filterParam->taxon,
			'source' =>$filterParam->source
		));
		return $form;
	}
	
	public function processFilterForm(Form $form){
		$values = $form->getValues();
		if($this->user->isLoggedIn() == FALSE){
			$values['source'] = 1;
		}
		$this->setFilterForm($values->taxon);
		$this->redirect("default", array('page'=>1,'columnOrder'=>'taxon','order'=>'ASC'));
	}
	
	public function actionOut(){
		$this->getUser()->logout();
		$session = $this->context->getService('session');
		$filterParam = $session->getSection($this->sessName);
		$filterParam->source = 1;
		$filterParam->taxon = NULL;
		$this->redirect('Homepage:default');
	}
    
    
    
    public function actionDoc(){
		if($this->user->isLoggedIn() == FALSE){
			$this->redirect('Homepage:default');
		}
	}
	
	public function renderDefault($page = 1, $columnOrder = 'taxon', $order = 'ASC'){
		$session = $this->context->getService('session');
		$filterParam = $session->getSection($this->sessName);
		if(($filterParam->taxon != NULL)){
			$where = array('taxon' => "%".str_replace(" ", "% ",$filterParam->taxon)."%");
		}else{
			$where = NULL;
		}

		$countWhere = $this->viewTaxonRepository->getCountAll($where);
		$paginator = $this->getPaginator($countWhere, $page);
		$collection = $this->viewTaxonRepository->getDataSource($paginator->getLength(), $paginator->getOffset(), array($columnOrder=>$order),$where);
		$count = $this->viewTaxonRepository->getCountAll();

		$isOrdered = $order;

		$this->template->items = $collection;
		$this->template->paginator = $paginator;
		$this->template->columnOrder = $columnOrder;
		$this->template->isOrdered = $isOrdered;
		$this->template->count = $count;
		$this->template->countWhere = $countWhere;
		$this->template->exportfile = $this->exportRepository->getFileName();
		$this->template->last = $this->downloadRepository->getLast();
		$this->template->countDownload = $this->downloadRepository->getCount();
		$this->template->source = $filterParam->source;
	}
	
	public function handleFile($filename){
		$collections = $this->taxonRepository->getDataSource(20000,0);
		$this->exportRepository->start($collections,$filename, $this->systemSettingsRepository->getName());
		$result = "\"result\":\"OK\"";
		$this->downloadRepository->save(date('Y-m-d H:i:s'));
		$this->sendResponse(new TextResponse("{".$result."}"));
	}
	
	public function handleDelete($taxonid){
		if($this->user->isLoggedIn()){
			$item = $this->taxonRepository->findById($taxonid);
			if($this->downloadRepository->isDeleteOk($item->getAddDateISO())){
				$this->taxonRepository->delete($taxonid);
				$this->redirect('Homepage:default');
			}else{
				$viewItem = $this->viewTaxonRepository->findById($taxonid);
				$taxon = NULL;
				if(isset($viewItem->taxon)){
					$taxon = $viewItem->taxon;
				}
				//$this->flashMessage('Taxon '.$taxon. ' nelze smazat, protože po jeho přidání byl již stažen checklist','error');
				$this->redirect('Taxon:delete', array('taxonid'=>$taxonid));
			}
		}else{
			$this->flashMessage('Taxon nelze smazat, protože nejste přihlášen">','error');
		}
	}
	
	
	
	/**
	 * Get paginator
	 * @param int $countWhere
	 * @param int $page
	 * @return \Nette\Utils\Paginator
	 */
	private function getPaginator($countWhere,$page){
		$paginator = new Paginator;
		$paginator->setItemCount($countWhere);
		$paginator->setItemsPerPage(22);
		$paginator->setPage($page);
		return $paginator;
	}
	

	/**
	 * set session from find form
	 * @param array $value
	 */
	protected function setFilterForm($taxon){
		$session = $this->context->getService('session');
		$myParam = $session->getSection($this->sessName);
		$myParam->taxon = $taxon;
	}
}
