<?php

use Nette\Application\UI\Form;

class TaxonPresenter extends BasePresenter{
	private $taxonRepository;
	private $viewtaxonRepository;
	private $familyRepository;


	public function startup() {
		parent::startup();
		$this->taxonRepository = $this->context->getService('taxonRepository');
		$this->viewtaxonRepository = $this->context->getService('viewtaxonRepository');
		$this->familyRepository = $this->context->getService('familyRepository');
	}
	
	public function actionEdit(){
		if($this->user->isLoggedIn() == FALSE){
			$this->redirect('Homepage:default');
		}
	}
	
	public function actionDefault(){
		$this->redirect('Homepage:default');
	}
	
	public function actionDelete(){
		if($this->user->isLoggedIn() == FALSE){
			$this->redirect('Homepage:default');
		}
	}

	public function createComponentEditForm(){
		$id = $this->getParameter('taxonid');
		$defaultValue = $this->getDefaultFormValue($id);
		if($defaultValue['family']){
			$family = $defaultValue['family'];
		}else{
			$family = NULL;
		}
		$form = new Form();
		$form->addText('id','ID');
		$form->addText('family', 'Čeleď');
		$form->addText('familysample', 'Čeleď');
		$form->addSelect('genushybridmarker','Příznak mezirodového hybrida',array('×'=>'×'))
			->setPrompt('Zvolte příznak');
		$form->addText('genus','Rod')
			->addRule(Form::FILLED, 'Zadejte rod');
		$form->addText('infragenericmarker','Vnitrorodový příznak');
		$form->addText('infragenericep', 'Vnitrorodové jméno');
		$form->addSelect('specieshybridmarker','Příznak mezidruhového hybrida',array('×'=>'×'))
			->setPrompt('Zvolte příznak');
		$form->addText('speciesep','Druhové jméno');
		$form->addText('speciesauthor','Autor druhového jména');
		$form->addText('aggregatmarker','Příznak pro agregát');
		$form->addText('infraspecificmarker','Vnitrodruhový příznak');
		$form->addText('infraspecificep','Vnitrodruhové jméno');
		$form->addText('infraspecificauthor','Autor vnitrodruhového jména');
		$form->addText('cultivgroupmarker','Příznak skupiny kultivarů');
		$form->addText('cultivmarker','Příznak kultivaru');
		$form->addText('cultivname','Jméno kultivaru');
		$form->addText('czname','České jméno');
		$form->addText('note','Poznámka');
		$form->onSuccess[] = (array($this,'processEditForm'));
		$form->addSubmit('submit','Uložit');
		$form->addSubmit('cancel','Zpět');
		$form->setDefaults(array(
			'id'=>$defaultValue['id'],
			'family'=>$defaultValue['family'],
			'familysample'=>$defaultValue['familyname'],
			'genushybridmarker'=>$defaultValue['genushybridmarker'],
			'genus'=>$defaultValue['genus'],
			'infragenericmarker' =>$defaultValue['infragenericmarker'],
			'infragenericep' => $defaultValue['infragenericep'],
			'specieshybridmarker' =>$defaultValue['specieshybridmarker'],
			'speciesep' => $defaultValue['speciesep'],
			'speciesauthor' => $defaultValue['speciesauthor'],
			'aggregatmarker' => $defaultValue['aggregatmarker'],
			'infraspecificmarker' => $defaultValue['infraspecificmarker'],
			'infraspecificep' => $defaultValue['infraspecificep'],
			'infraspecificauthor' => $defaultValue['infraspecificauthor'],
			'cultivgroupmarker' => $defaultValue['cultivgroupmarker'],
			'cultivmarker' => $defaultValue['cultivmarker'],
			'cultivname' => $defaultValue['cultivname'],
			'czname' => $defaultValue['czname'],
			'note' => $defaultValue['note'],
			'family' => $defaultValue['family']
		));
		return $form;
	}

	public function processEditForm(Form $form){
		if($this->user->isLoggedIn()){
			$httpddata = $form->getHttpData();
			if(isset($httpddata['cancel'])){
				$this->redirect('Homepage:default');
			}
			$values = $form->getValues();
			$formValues = $this->getFormValue($values);
			$items2 = $this->taxonRepository->getDataSource(20000,0,NULL, $this->getWhere($formValues));
			if(strlen($values['id']) == 0){		
				if($items2){
					$this->flashMessage("<img src=../images/dialog-error.png alt='error'>&nbsp;Taxon nebyl uložen, protože ".str_replace("  "," ",$formValues['genus']." ".$formValues['infragenericep']." ".$formValues['speciesep']." ".$formValues['aggregatmarker']." ".$formValues['infraspecificep']." ".$formValues['cultivname'])." již byl zadán","error");
					return;
				}
				$res = $this->taxonRepository->save($formValues);
				if($res == TRUE){
					$this->flashMessage("<img src=../images/dialog-information.png alt='info'>&nbsp;Taxon byl uložen",'info');
				}else{
					$this->flashMessage("<img src=../images/dialog-error.png alt='error'>&nbsp;Taxon nebyl uložen",'error');
				}
				$this->redirect("Taxon:edit");
			}else{
				$res = $this->taxonRepository->update($formValues);
				if($res == TRUE){
					$this->flashMessage("Taxon byl uložen",'info');
				}else{
					$this->flashMessage('Taxon nebyl uložen','error');
				}
				$this->redirect('Homepage:default');
			}
		}
	}
	
	public function createComponentEdit2Form(){
		$id = $this->getParameter('taxonid');
		$form = new Form();
		$form->addHidden("id");
		$form->addCheckbox("breakLink","Zrušit přiřazení taxonu");
		$form->onSuccess[] = (array($this,'processEdit2Form'));
		$form->addSubmit('submit','Uložit');
		$form->addSubmit('cancel','Zpět');
		$form->setDefaults(array(
			'id'=>$id
		));
		return $form;
	}
	
	public function processEdit2Form(Form $form){
		if($this->user->isLoggedIn()){
			$httpddata = $form->getHttpData();
			if(isset($httpddata['cancel'])){
				$this->redirect('Homepage:default');
			}
			$values = $form->getValues();
			$this->flashMessage($values->breakLink);
			if($values->breakLink == 1){
				$this->taxonRepository->deleteChange($values->id,null);
				$this->flashMessage("Přiřazení bylo zrušeno",'info');
				
			}
		}
		$this->redirect("Homepage:default");
	}
	
	public function createComponentDeleteForm(){
		$id = $this->getParameter('taxonid');
		$form = new Form();
		$form->addText('oldid');
		$form->addText('newid');
		$form->onSuccess[] = (array($this,'processDeleteForm'));
		$form->addSubmit('submit','Uložit');
		$form->addSubmit('cancel','Zpět');
		$form->setDefaults(array(
				'oldid'=>$id
			)
		);
		
		return $form;
	}
	
	public function processDeleteForm(Form $form){
		if($this->user->isLoggedIn()){
			$httpddata = $form->getHttpData();
			if(isset($httpddata['cancel'])){
				$this->redirect('Homepage:default');
			}
			$values = $form->getValues();
			if($values->newid && $values->oldid){
				$viewOld = $this->viewtaxonRepository->findById($values->oldid);
				$viewNew = $this->viewtaxonRepository->findById($values->newid);
				if($viewNew){
					$this->taxonRepository->deleteChange($values->oldid, $values->newid);
					$this->flashMessage("Taxon ".$viewOld->taxon." byl změněn na ".$viewNew->taxon);
					$this->redirect("Homepage:default");
				}else{
					$this->flashMessage("Nesprávné jméno taxonu");
				}
			}else{
				$this->flashMessage("Není zadán taxon",'error');
				$this->redirect("delete", array('taxonid'=>$values->oldid));
			}
		}
	}

	public function renderEdit($taxonid){
		$synonyms = NULL;
		$item = NULL;
		$headline = "Nový taxon";
		if($taxonid){
			$item = $this->taxonRepository->findById($taxonid);
			$headline = "Editace taxonu";
		}
		$taxon = null;
		$taxonvalid = null;
		if($taxonid){
			$itemView = $this->viewtaxonRepository->findById($taxonid);
			$taxon = $itemView->taxon;
			$taxonvalid = $itemView->taxonvalid;
		}
		$this->template->synonyms = $synonyms;
		$this->template->item = $item;
		$this->template->headline = $headline;
		$this->template->taxon = $taxon;
		$this->template->taxonvalid = $taxonvalid;
	}
	
	public function renderDelete($taxonid){
		$headline = "Smazat taxon";
		$viewItem = NULL;
		$oldtaxon = NULL;
		if($taxonid){
			$viewItem = $this->viewtaxonRepository->findById($taxonid);
			if(isset($viewItem->taxon)){
				$oldtaxon = $viewItem->taxon;
			}
		}
		$this->template->headline = $headline;
		$this->template->oldtaxon = $oldtaxon;
	}

	private function getDefaultFormValue($id){
		$item = NULL;
		$value = NULL;
		if($id){
			$item = $this->taxonRepository->findById($id);
			$value['id'] = $item->getId();
			$value['family'] = $item->family;
			$value['familyname'] = $item->familyname;
			$value['genushybridmarker'] = $item->genushybridmarker;
			$value['genus'] = $item->genus;
			$value['infragenericmarker'] = $item->infragenericmarker;
			$value['infragenericep'] = $item->infragenericep;
			$value['specieshybridmarker'] = $item->specieshybridmarker;
			$value['aggregatmarker'] = $item->aggregatmarker;
			$value['speciesep'] = $item->speciesep;
			$value['speciesauthor'] = $item->speciesauthor;
			$value['infraspecificmarker'] = $item->infraspecificmarker;
			$value['infraspecificep'] = $item->infraspecificep;
			$value['infraspecificauthor'] = $item->infraspecificauthor;
			$value['cultivgroupmarker'] = $item->cultivgroupmarker;
			$value['cultivmarker'] = $item->cultivmarker;
			$value['cultivname'] = $item->cultivname;
			$value['czname'] = $item->czname;
			$value['note'] = $item->note;
		}else{
			$value['id'] = NULL;
			$value['family'] = NULL;
			$value['familyname'] = NULL;
			$value['genushybridmarker'] = NULL;
			$value['genus'] = NULL;
			$value['infragenericmarker'] = NULL;
			$value['infragenericep'] = NULL;
			$value['specieshybridmarker'] = NULL;
			$value['aggregatmarker'] = NULL;
			$value['speciesep'] = NULL;
			$value['speciesauthor'] = NULL;
			$value['infraspecificmarker'] = NULL;
			$value['infraspecificep'] = NULL;
			$value['infraspecificauthor'] = NULL;
			$value['cultivgroupmarker'] = NULL;
			$value['cultivmarker'] = NULL;
			$value['cultivname'] = NULL;
			$value['czname'] = NULL;
			$value['note'] = NULL;
			$value['family'] = NULL;  
		}
		return $value;
	}

	private function getFormValue($values){
		if(strlen($values->id) == 0){
			$valuearr['id'] = $this->getId($values);
			$valuearr['add'] = date('Y-m-d H:i:s');
			$valuearr['edit'] = date('Y-m-d H:i:s');
			$valuearr['userid'] = $this->user->getId();
		}else{
			$valuearr['id'] = $values->id;
			$valuearr['edit'] = date('Y-m-d H:i:s');
			$valuearr['change'] = $this->user->getId();
		}
		$valuearr['genushybridmarker'] = $values->genushybridmarker;
		$valuearr['genus'] = $values->genus;
		$valuearr['infragenericmarker'] = $values->infragenericmarker;
		$valuearr['infragenericep'] = $values->infragenericep;
		$valuearr['specieshybridmarker'] = $values->specieshybridmarker;
		$valuearr['aggregatmarker'] = $values->aggregatmarker;
		$valuearr['speciesep'] = $values->speciesep;
		$valuearr['speciesauthor'] = $values->speciesauthor;
		$valuearr['infraspecificmarker'] = $values->infraspecificmarker;
		$valuearr['infraspecificep'] = $values->infraspecificep;
		$valuearr['infraspecificauthor'] = $values->infraspecificauthor;
		$valuearr['cultivgroupmarker'] = $values->cultivgroupmarker;
		$valuearr['cultivmarker'] = $values->cultivmarker;
		$valuearr['cultivname'] = $values->cultivname;
		$valuearr['czname'] = $values->czname;
		$valuearr['note'] = $values->note;
		$valuearr['family'] = $values->family;
		return $valuearr;
	}

	/**
	 * Get unique identifier of taxon
	 * @param array $values
	 * @return string
	 */
	private function getId($values){
		$id= substr($values["genus"],0,4)." ".substr($values["speciesep"],0,3)." ".substr($values["infraspecificep"],0,3)." ".substr($values["cultivname"],0,3);
		$id = str_replace("  "," ",$id);
		$id = str_replace("  "," ",$id);
		$NumberIDStr=$values["genus"].$values["infragenericep"].$values["speciesep"].$values["aggregatmarker"].$values["infraspecificep"].$values["cultivname"];
		$NumberID = 0;
		$NumberIDStr = trim($NumberIDStr);
		for ($i = 0; $i <= strlen($NumberIDStr); $i++) {
			$NumberID = $NumberID + ord(substr($NumberIDStr,$i,1));
		}
		$id = trim($id).$NumberID;
		return $id;
	}

	private function getWhere($values){
		$where['genus'] = $values['genus'];
		if(strlen($values['infragenericep']) > 0){
			$where['infragenericep'] = $values['infragenericep'];
		}
		if(strlen($values['aggregatmarker'])>0){
			$where['aggregatmarker'] = $values['aggregatmarker'];
		}
		if(strlen($values['speciesep'])>0){
			$where['speciesep'] = $values['speciesep'];
		}
		/*if(strlen($values['infraspecificmarker'])>0){
			$where['infraspecificmarker'] = $values['infraspecificmarker'];
		}*/
		if(strlen($values['infraspecificep'])>0){
			$where['infraspecificep'] = $values['infraspecificep'];
		}
		if(strlen($values['cultivname'])>0){
			$where['cultivname'] = $values['cultivname'];
		}
		return $where;
	}
}