<?php

use Nette\Application\UI\Form;

class UserPresenter extends BasePresenter{
    
    private $userRepository;
    private $taxonRepository;
            
    public function startup(){
        parent::startup();
        //parent::__construct();
        $this->userRepository = $this->context->getService('userRepository');
        $this->taxonRepository = $this->context->getService('taxonRepository');
    }
    
    public function handleDelete($userid){
        $count = $this->taxonRepository->getCountUser($userid);
        if($count == 0){
            $this->userRepository->delete($userid);
        }else{
            $this->flashMessage("<img id='flash-icon' src='../images/dialog-error.png'><span class='flash-text'>Nelze smnazat uživatele, protože již zadal taxony</span> <img id='flash-cancel' src='../images/dialog-close.png'>",'error');
        }
    }
    
    public function actionEdit(){
        If($this->user->isLoggedIn() == FALSE){
            $this->redirect('Homepage:default');
        }
    }
    
    public function actionDefault(){
        If($this->user->isLoggedIn() == FALSE){
            $this->redirect('Homepage:default');
        }
    }
    
    public function renderDefault(){
        $collections = $this->userRepository->getDataSource(1000,0,array('id'=>'ASC'));
        $this->template->items = $collections;
    }
    public function renderEdit($id){
        If($id){
            $headline = "Upravit uživatele";
        }else{
            $headline = "Nový uživatel";
        }
        $this->template->headline = $headline;
    }


    public function createComponentEditForm(){
        $id = $this->getParameter('id');
        $defaultValue = $this->getDefaultFormValue($id);
        $form = new Form();
        $form->addText('id','ID');
        $form->addText('firstname','Jméno');
        $form->addText('surname','Příjmení')
                ->addRule(Form::FILLED, 'Zadejte příjmení');
        $form->addText('username','Uživatelské jméno')
                ->addRule(Form::FILLED, 'Zadejte login');
        $form->addPassword('password1','Heslo');
        $form->addPassword('password2','Ověření hesla');
        $form->addText('email','Email')
                ->addRule(Form::FILLED, 'Zadejte email');
        $form->addSubmit('send','Uložit');
        $form->onSuccess[] = (array($this,'processEditForm'));
        $form->setDefaults(array(
            'id' => $defaultValue['id'],
            'firstname'=>$defaultValue['firstname'],
            'surname' => $defaultValue['surname'],
            'username' => $defaultValue['username'],
            'email' => $defaultValue['email']
        ));
        return $form;
        
    }
    
    public function processEditForm(Form $form){
        if($this->user->isLoggedIn()){
            $values = $form->getValues();
            if($values['password1'] != $values['password2']){
                $form->addError('Neshodují se hesla');
                return;
            }else{
                if((strlen($values['password1']) >= 8 || strlen($values['password1']) == 0)){
                    if(strlen($values['id'])>0){
                        $this->flashMessage("<img id='flash-icon' src='../images/dialog-information.png'><span class='flash-text'>Uživatel <span class='info-stress'>". $values['firstname']." ". $values['surname']."</span> byl uložen</span> <img id='flash-cancel' src='../images/dialog-close.png'>","info");
                        $this->userRepository->save($this->getFormData($values));
                        $this->redirect('User:default');
                    }elseif(strlen($values['id'])>0 || strlen($values['password1']) >= 8){
                        $this->flashMessage('<img id="flash-icon" src="../images/dialog-information.png"><span class="flash-text">Uživatel <span class="info-stress">'. $values['firstname']." ". $values['surname'].'</span> byl uložen</span> <img id="flash-cancel" src="../images/dialog-close.png">','info');
                        $this->userRepository->save($this->getFormData($values));
                        $this->redirect('User:default');
                    }else{
                        $form->addError('Heslo musí mít minimálně 8 znaků');
                    }
                }else{
                    $form->addError('Heslo musí mít minimálně 8 znaků');
                }
            }
        }else{
            $this->flashMessage("<img id='flash-icon' src='../images/dialog-warning.png'><span class='flash-text'>Neoprávněný přístup</span> <img id='flash-cancel' src='../images/dialog-close.png'>","error");
        }
    }
    
    private function getDefaultFormValue($id){
        $values = NULL;
        if($id){
            $item = $this->userRepository->findById($id);
            $values['id'] = $item->getId();
            $values['firstname'] = $item->firstname;
            $values['surname'] = $item->surname;
            $values['username'] = $item->username;
            $values['email'] = $item->email;
        } else {
            $values['id'] = NULL;
            $values['firstname'] = NULL;
            $values['surname'] = NULL;
            $values['username'] = NULL;
            $values['email'] = NULL;
        }
        return $values;
    }
    
    public function getFormData($formvalues){
        if($formvalues->id){
            $value['id']= $formvalues['id'];
        }else{
            $value['id']= NULL;
        }
        $value['firstname'] = $formvalues['firstname'];
        $value['surname'] = $formvalues['surname'];
        $value['username'] = $formvalues['username'];
        if($formvalues['password1']){
             $value['password'] = $formvalues['password1'];
        }else{
            $value['password'] = NULL;
        }
        $value['email'] = $formvalues['email'];
        return $value;
    }
}
