<?php

namespace Test;

use Nette,
    Tester,
    Tester\Assert;

$container = require __DIR__ . '/../bootstrap.php';

class DownloadRepositoryTest extends Tester\TestCase{
    private $container;
    private $repository;
    
    public function __construct(Nette\DI\Container $container){
        $this->container = $container;
        $this->repository = $this->container->getService('downloadRepository');        
    }

    public function setUp(){
        \Tester\Environment::lock("db.lock",dirname('TEMP_DIR'));
        \Nette\Database\Helpers::loadFromFile( $this->container->getService('database.default'), __DIR__.'/../initialise_db.sql');
    }
    
    public function testGetCount(){
        $count = $this->repository->getCount();
        Assert::equal(10, $count);
    }
    
    public function testGetLast(){
        $last = $this->repository->getLast();
        Assert::equal('24. 10. 2016 16:52:48', $last);
    }
    
    public function testISDeleteOk(){
        $res = $this->repository->isDeleteOK('2016-10-24 16:59:59');
        Assert::true($res);
    }
    
    public function testISDeleteOk2(){
        $res = $this->repository->isDeleteOK('2016-10-23 16:59:59');
        Assert::false($res);
    }
    
    public function testSave(){
        $time = "2016-10-24 18:20:21";
        $this->repository->save($time);
        $row = $this->container->getService('database.default')->query('SELECT count(cId) AS count FROM taxony_tblDownload WHERE cTime = ?',$time)->fetch();
        Assert::equal(1, $row['count']);
    }
    
}
$test = new DownloadRepositoryTest($container);
$test->run();
