<?php
namespace Test;

use Nette,
    Tester,
    Tester\Assert;

$container = require __DIR__ . '/../bootstrap.php';

class TaxonMapperTest extends Tester\TestCase
{
    private $container;
    private $mapper;
    
    function __construct(Nette\DI\Container $container) {
        $this->container = $container;
        $this->mapper = $this->container->getService("taxonMapper");
    }
    
    function setUp(){
        \Tester\Environment::lock("db.lock",dirname('TEMP_DIR'));
        \Nette\Database\Helpers::loadFromFile($this->container->getService('database.default'), __DIR__."/../initialise_db.sql");
    }
    
    public function testGetAllNULOrder(){
        $res = $this->mapper->getAll(10000,0,null);
        Assert::equal(7722, count($res));
    }
    
    public function testSave(){
        $item['genushybridmarker'] = "x";
        $item['genus'] = "testgenus";
        $item['infragenericmarker'] = "ser.";
        $item['infragenericep'] = "Glandulosii";
        $item['specieshybridmarker'] = "x";
        $item['aggregatmarker'] = "agg.";
        $item['speciesep'] = "species";
        $item['speciesauthor'] = "speciesauthor";
        $item['infraspecificmarker'] = "c";
        $item['infraspecificep'] = "infraspecificep";
        $item['infraspecificauthor'] = "infraspecificauthor";
        $item['cultivgroupmarker'] = "cgm";
        $item['cultivmarker'] = "cultiv.";
        $item['cultivname'] = "cultivname";
        $item['czname'] = "czname";
        $item['abbrev'] = "abbrev";
        $item['note'] = "note";
        $item['id_tax'] = "id_tax";
        $item['add'] = "2016-09-30 15:25:30";
        $item['edit'] = "2016-09-30 15:25:30";
        $item['userid'] = 1;
        $item['change'] = 2;
        $item['id'] = 'tesgns';
        
        
        
        $res = $this->mapper->save($item);
        $rows = $this->container->getService('database.default')->query("SELECT * FROM taxony_tblTaxons WHERE cGenus = '".$item['genus']."';" );
        Assert::equal(1, count($rows));
        Assert::true($res);
    }
    
    public function testUpdate(){
        $item['genushybridmarker'] = "x";
        $item['genus'] = "testgenus";
        $item['infragenericmarker'] = "ser.";
        $item['infragenericep'] = "Glandulosii";
        $item['specieshybridmarker'] = "x";
        $item['aggregatmarker'] = "agg.";
        $item['speciesep'] = "species";
        $item['speciesauthor'] = "speciesauthor";
        $item['infraspecificmarker'] = "var.";
        $item['infraspecificep'] = "infraspecificep";
        $item['infraspecificauthor'] = "infraspecificauthor";
        $item['cultivgroupmarker'] = "cgm";
        $item['cultivmarker'] = "cultiv.";
        $item['cultivname'] = "cultivname";
        $item['czname'] = "czname";
        $item['abbrev'] = "abbrev";
        $item['note'] = "note";
        $item['id_tax'] = "id_tax";
        $item['add'] = "2016-09-30 15:25:30";
        $item['edit'] = "2016-09-30 15:25:30";
        $item['userid'] = 1;
        $item['change'] = 2;
        $item['id'] = 'Abie cep1644';
        
        
        $updateditem = NULL; 
        $res = $this->mapper->update($item);
        $rows = $this->container->getService('database.default')->query("SELECT * FROM taxony_tblTaxons WHERE cId = 'Abie cep1644';" );
        Assert::true($res);
        foreach($rows as $row){
            $updateditem['genushybridmarker'] = $row['cGenusHybridMarker'];
            $updateditem['genus'] = $row['cGenus'];
            $updateditem['infragenericmarker'] = $row['cInfraGenericMarker'];
            $updateditem['infragenericep'] = $row['cInfraGenericEp'];
            $updateditem['specieshybridmarker'] = $row['cSpeciesHybridMarker'];
            $updateditem['aggregatmarker'] = $row['cAggregatMarker'];
            $updateditem['speciesep'] = $row['cSpeciesEp'];
            $updateditem['speciesauthor'] = $row['cSpeciesAuthor'];
            $updateditem['infraspecificmarker'] = $row['cInfraSpecificMarker'];
            $updateditem['infraspecificep'] = $row['cInfraSpecificEp'];
            $updateditem['infraspecificauthor'] = $row['cInfraSpecificAuthor'];
            $updateditem['cultivgroupmarker'] = $row['cCultivGroupMarker'];
            $updateditem['cultivmarker'] = $row['cCultivMarker'];
            $updateditem['cultivname'] = $row['cCultivName'];
            $updateditem['czname'] = $row['cCZName'];
            $updateditem['abbrev'] = $row['cAbbrev'];
            $updateditem['note'] = $row['cNote'];
            $updateditem['id_tax'] = $row['cID_tax'];
            $updateditem['add'] = $row['cAdd'];
            $updateditem['edit'] = $row['cEdit'];
            $updateditem['userid'] = $row['cUserId'];
            $updateditem['change'] = $row['cChange'];
        }
        Assert::equal($item['genushybridmarker'], $updateditem['genushybridmarker']);
        Assert::equal($item['genus'], $updateditem['genus']);
        Assert::equal($item['infragenericmarker'], $updateditem['infragenericmarker']);
        Assert::equal($item['infragenericep'], $updateditem['infragenericep']);
        Assert::equal($item['specieshybridmarker'], $updateditem['specieshybridmarker']);
        Assert::equal($item['aggregatmarker'], $updateditem['aggregatmarker']);
        Assert::equal($item['speciesep'], $updateditem['speciesep']);
        Assert::equal($item['speciesauthor'], $updateditem['speciesauthor']);
        Assert::equal($item['infraspecificmarker'], $updateditem['infraspecificmarker']);
        Assert::equal($item['infraspecificep'], $updateditem['infraspecificep']);
        Assert::equal($item['infraspecificauthor'], $updateditem['infraspecificauthor']);
        Assert::equal($item['cultivgroupmarker'], $updateditem['cultivgroupmarker']);
        Assert::equal($item['cultivmarker'], $updateditem['cultivmarker']);
        Assert::equal($item['cultivname'], $updateditem['cultivname']);
        Assert::equal($item['czname'], $updateditem['czname']);
        Assert::equal($item['abbrev'], $updateditem['abbrev']);
        Assert::equal($item['note'], $updateditem['note']);
        Assert::equal($item['id_tax'], $updateditem['id_tax']);
        Assert::equal($item['add'], (string)$updateditem['add']);
        Assert::equal($item['edit'], (string)$updateditem['edit']);
        Assert::equal($item['userid'], $updateditem['userid']);
        Assert::equal($item['change'], $updateditem['change']);
    }
    
    public function testDelete(){
        $id = 'Acer cam1357';
        $this->mapper->delete($id);
        $rows = $this->container->getService('database.default')->query("SELECT * FROM taxony_tblTaxons WHERE cId = '".$id."';" )->fetchAll();
        Assert::equal(0, count($rows));
    }
    
    public function testFindBy(){
        $row = $this->mapper->findBy(array('column' => 'id','value' => 'Acon var1928','datatype' => 's'));
        Assert::equal(1, count($row));
    }
    
    public function testGetCount(){
        $count = $this->mapper->getCount(array('column'=>'userid','value'=>4));
        Assert::equal(2, $count);
    }
    
    public function testSetNewAcceptNames(){
        $this->mapper->setNewAcceptNames('Care atr1148','Care acu1036');
        $old = $this->container->getService('database.default')->query("SELECT count(*) AS count from taxony_tblTaxons WHERE cID_tax = 'Care atr1148'")->fetch();
        $new = $this->container->getService('database.default')->query("SELECT count(*) AS count from taxony_tblTaxons WHERE cID_tax = 'Care acu1036'")->fetch();
        Assert::equal(0, $old->count);
        Assert::equal(4, $new->count);
    }
}
$test = new TaxonMapperTest(($container));
$test->run();
