<?php
namespace Test;

use Nette,
    Tester,
    Tester\Assert;

$container = require __DIR__ . '/../bootstrap.php';


class UserMapperTest extends Tester\TestCase
{
    private $container;
    private $mapper;

    function __construct(Nette\DI\Container $container){
        $this->container = $container;
        $this->mapper = $this->container->getService('userMapper');  
    }


    function setUp(){
        \Tester\Environment::lock("db.lock",dirname('TEMP_DIR'));
        \Nette\Database\Helpers::loadFromFile( $this->container->getService('database.default'), __DIR__.'/../initialise_db.sql');
    }
    
    public function testGetAllNullOrder(){
        $res = $this->mapper->getAll(6,0,null);
        Assert::equal(4,count($res));
    }
    
    public function testGetAllOrder(){
        $res = $this->mapper->getAll(6,0,array('id'=>'DESC'));
        Assert::equal(4,count($res));
    }
    
    public function testGetAllWhere(){
        $row = $this->mapper->getAll(6,0,null,array('column'=>'surname', 'value'=>'Lepší'));
        Assert::equal(2,count($row));
    }
    
    /**
     * test save new user
     * @see save()
     */
    public function testSaveNewUser(){           
        $userItem['username'] = 'leps';
        $userItem['firstname'] = 'Jan Šuspa';
        $userItem['surname'] = 'Leps';
        $userItem['email'] = 'leps@prf.jcu.cz';
        $userItem['password'] = 'suspa';
        $userItem['id'] = null;
        
        $res = $this->mapper->save($userItem);
        $count = $this->container->getService('database.default')->query("select count(*) AS count from taxony_tblUsers where cUserName='leps'")->fetch();
        Assert::equal(1,$count->count);
        Assert::true($res);
    }
    
    /**
     * test update old user
     * @see save()
     */
    public function testUpdateUser(){
        $username = NULL;
        $firstname = NULL;
        $surname = NULL;
        $email = NULL;
        $password = NULL;
        
           
        $passwordHash = '6176e2c265298428b2471058b3835ffcbb9409c35a00926e4bef09fb59ac7cb6';
        $mockUserItem['username'] = 'admin';
        $mockUserItem['firstname'] = 'Tester Testerovitsch2';
        $mockUserItem['surname'] = 'Testerovitschenko6';
        $mockUserItem['email'] = 'tester@testerov.cz';
        $mockUserItem['password'] = 'testtest2';
        $mockUserItem['id'] = 1;
       
           
        $res = $this->mapper->save($mockUserItem);
        $rows = $this->container->getService('database.default')->query("select * from taxony_tblUsers where cId = 1")->fetchAll();
        foreach($rows as $row){
            $username = $row->cUserName;
            $firstname = $row->cFirstName;
            $surname = $row->cSurName;
            $password = $row->cPassword;
            $email = $row->cEmail;
            
        }
        Assert::equal(1, count($rows));
        Assert::equal($mockUserItem['username'],$username);
        Assert::equal($mockUserItem['firstname'], $firstname);
        Assert::equal($mockUserItem['surname'], $surname);
        Assert::equal($mockUserItem['email'], $email);
        Assert::equal($passwordHash, $password);
    }
    
    public function testDelete(){
        $this->mapper->delete(3);
        $count = $this->container->getService('database.default')->query("select count(*) AS count from taxony_tblUsers")->fetch();
        Assert::equal(3,$count->count);
    }
    
    public function testFindBy(){
        $res = $this->mapper->findBy(array('column'=>'username','value'=>'admin', 'datatype'=>'s'));
        Assert::equal(1, count($res));
    }
}
$test = new UserMapperTest($container);
$test->run();