<?php
namespace Test;

use Nette,
	Tester,
	Tester\Assert;

$container = require __DIR__ . '/../bootstrap.php';

class UserRepositoryTest extends Tester\TestCase
{
    private $container;
    private $repository;

    function __construct(Nette\DI\Container $container){
        $this->container = $container;
        $this->repository = $this->container->getService('userRepository');        
    }

    function setUp(){
        \Tester\Environment::lock("db.lock",dirname('TEMP_DIR'));
        \Nette\Database\Helpers::loadFromFile( $this->container->getService('database.default'), __DIR__.'/../initialise_db.sql');
    }
    
    public function testGetDataSource(){
        $res = $this->repository->getDataSource(6,0,array('id'=>'ASC'));    
        Assert::equal(4, count($res));
    }
    
    public function testGetAllWhere(){
        $row = $this->repository->getDataSource(6,0,null,array('column'=>'surname', 'value'=>'Lepší'));
        Assert::equal(2,count($row));
    }
    
    public function testSaveNewUser(){
        $userItem['username'] = 'leps';
        $userItem['firstname'] = 'Jan Šuspa';
        $userItem['surname'] = 'Leps';
        $userItem['email'] = 'leps@prf.jcu.cz';
        $userItem['password'] = 'suspa';
        $userItem['id'] = null;
        
        $res = $this->repository->save($userItem);
        $count = $this->container->getService('database.default')->query("select count(*) AS count from taxony_tblUsers where cUserName='leps'")->fetch();
        Assert::equal(1,$count->count);
        Assert::true($res);
    }
    
    public function testDelete(){
        $this->repository->delete(3);
        $count = $this->container->getService('database.default')->query("select count(*) AS count from taxony_tblUsers")->fetch();
        Assert::equal(3,$count->count);
    }
    
    public function testFindById(){
        $res = $this->repository->findById(1);
        Assert::equal(1, count($res));
    }
    
    public function testFindByUserName(){
        $res = $this->repository->findByUserName('admin');
        Assert::equal(1, count($res));
    }
    
    public function testGetWhere(){
        $count = $this->repository->getCount(array('column'=>'userid','value'=>4));
        Assert::equal(0, $count);
    }
    
}
$test = new UserRepositoryTest($container);
$test->run();
