<?php
namespace Test;

use Nette,
    Tester,
    Tester\Assert;

$container = require __DIR__ . '/../bootstrap.php';

class ViewTaxonMapperTest extends Tester\TestCase
{
    private $container;
    private $mapper;
    
    public function __construct(Nette\DI\Container $container) {
        $this->container = $container;
        $this->mapper = $this->container->getService("viewtaxonMapper");
    }
    
    public function setUp(){
        \Tester\Environment::lock("db.lock",dirname('TEMP_DIR'));
        \Nette\Database\Helpers::loadFromFile($this->container->getService('database.default'), __DIR__."/../initialise_db.sql");
    }
    
    public function testGetAllNullOrder(){
        $res = $this->mapper->getAll(10000,0,null);
        Assert::equal(7684, count($res));
    }
    
    public function testGetCountAll(){
        $res = $this->mapper->getCountAll(array('column' =>'taxon', 'value'=> 'Picea%'));
        Assert::equal(9, $res);
    }
    
    public function testGetAll(){
        $res = $this->mapper->getAll(10000,0, null,array('column' =>'taxon', 'value'=> 'Picea%'));
        Assert::equal(9, count($res));
    }
    
    public function testGetAcceptName(){
        $res = $this->mapper->getAcceptNames(10000,0,null);
        Assert::equal(5491, count($res));
    }
    
    public function testGetCountAcceptNames(){
        $res = $this->mapper->getCountAcceptNames(array('column' =>'taxon', 'value'=> 'Picea%'));
        Assert::equal(8, $res);
    }

    public function testGetSynonym(){
        $res = $this->mapper->getSynonyms('Leon sax1943');
        Assert::equal(8, count($res));
    }
    
    public function testGetNoAcceptName(){
        $res = $this->mapper->getNoAcceptName(10000,0,null);
        Assert::equal(38, count($res));
    }
    
    public function testCountNoAcceptNames(){
        $res = $this->mapper->countNoAcceptNames();
        Assert::equal(38, $res);
    }

}
$test = new ViewTaxonMapperTest(($container));
$test->run();