<?php
namespace Test;

use Nette,
    Tester,
    Tester\Assert;

$container = require __DIR__ . '/../bootstrap.php';

class ViewTaxonRepositoryTest extends Tester\TestCase{
    private $container;
    private $repository;
    
    public function __construct(Nette\DI\Container $container){
        $this->container = $container;
        $this->repository = $this->container->getService('viewtaxonRepository');        
    }

    public function setUp(){
        \Tester\Environment::lock("db.lock",dirname('TEMP_DIR'));
        \Nette\Database\Helpers::loadFromFile( $this->container->getService('database.default'), __DIR__.'/../initialise_db.sql');
    }
    
    public function testGetDataSource(){
        $res = $this->repository->getDataSource(10000,0,array('id'=>'ASC'));    
        Assert::equal(7684, count($res));
    }
    
    public function testGetCountAll(){
        $res = $this->repository->getCountAll(array('column' =>'taxon', 'value'=> 'Picea%'));
        Assert::equal(9, $res);
    }
    
    public function testGetAcceptNameArr(){
        $res = $this->repository->getAcceptNamesArr(10000,0);
        Assert::equal(5492, count($res));
    }
    
    public function testGetCountAcceptNames(){
        $res = $this->repository->getCountAcceptNames(array('column' =>'taxon', 'value'=> 'Picea%'));
        Assert::equal(8, $res);
    }
    
    public function testGetSynonyms(){
        $res = $this->repository->getSynonyms('Leon sax1943');
        Assert::count(8, $res);
    }
    
    public function testGetNoAcceptName(){
        $res = $this->repository->getNoAcceptNames(10000,0);
        Assert::count(38, $res);
    }
    
    public function testCountNoAcceptNames(){
        $count = $this->repository->getCountNoAcceptNames();
        Assert::equal(38, $count);
    }
    
    public function testFindById(){
        $res = $this->repository->findById('Acer pse1926');
        Assert::type("ViewTaxonItem", $res);
    }
    
    public function testFindById2(){
        $res = $this->repository->findById('Acer pse1926666');
        Assert::null( $res);
    }
}
$test = new ViewTaxonRepositoryTest($container);
$test->run();